@@ -1,7 +1,7 @@
 #! /bin/sh
 
 # GNU Mes --- Maxwell Equations of Software
-# Copyright © 2019,2020,2021 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+# Copyright © 2019,2020,2021,2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 #
 # This file is part of GNU Mes.
 #
@@ -30,6 +30,7 @@ fi
 . ./config.sh
 
 libc_mini_shared_SOURCES="
+lib/mes/__init_io.c
 lib/mes/eputs.c
 lib/mes/oputs.c
 "
@@ -74,7 +75,7 @@ libc_mini_SOURCES="$libc_mini_shared_SOURCES"
 
 if test $mes_libc = mes; then
     libc_mini_SOURCES="$libc_mini_SOURCES
-lib/mes/mini-write.c
+lib/mes/write.c
 "
 fi
 
@@ -107,8 +108,16 @@ lib/mes/ntoab.c
 lib/mes/oputc.c
 lib/mes/ultoa.c
 lib/mes/utoa.c
+"
+
+# /include/mes/lib-cc.h already defines __raise.c as a macro for __TCC__
+# if we include it in the target source lib it explodes when reading the
+# function definition
+if test $compiler != tcc; then
+    libmes_SOURCES="$libmes_SOURCES
 lib/stub/__raise.c
 "
+fi
 
 if test $mes_libc = mes; then
     libmes_SOURCES="$libmes_SOURCES
@@ -215,6 +224,7 @@ lib/linux/malloc.c
 lib/linux/_read.c
 lib/linux/time.c
 lib/linux/unlink.c
+lib/linux/wait4.c
 lib/linux/waitpid.c
 lib/linux/$mes_cpu-mes-$compiler/syscall.c
 lib/linux/getpid.c
