@@ -19,41 +19,29 @@
  */
 
 #include "mes/lib-mini.h"
-
 int main (int argc, char *argv[], char *envp[]);
 
 int
 _start ()
 {
-  asm ("mov____$i8,%eax !0");
-  asm ("mov____%eax,0x32 &__stdin");
-
-  asm ("mov____$i8,%eax !1");
-  asm ("mov____%eax,0x32 &__stdout");
-
-  asm ("mov____$i8,%eax !2");
-  asm ("mov____%eax,0x32 &__stderr");
-
-  asm ("mov____%ebp,%eax");
+  asm ("mov____%ebp,%eax");   //environ
   asm ("add____$i8,%eax !4");
-
   asm ("mov____(%eax),%eax");
   asm ("add____$i8,%eax !3");
-
   asm ("shl____$i8,%eax !0x02");
   asm ("add____%ebp,%eax");
-  asm ("mov____%eax,0x32 &environ");
   asm ("push___%eax");
 
-  asm ("mov____%ebp,%eax");
+  asm ("mov____%ebp,%eax");   // argv
   asm ("add____$i8,%eax !8");
   asm ("push___%eax");
 
-  asm ("mov____%ebp,%eax");
+  asm ("mov____%ebp,%eax");   // argc
   asm ("add____$i8,%eax !4");
   asm ("mov____(%eax),%eax");
   asm ("push___%eax");
 
+  __init_io ();
   main ();
 
   asm ("mov____%eax,%ebx");
