@@ -18,10 +18,10 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
 
 int
 eputc (int c)
 {
-  return fdputc (c, g_stderr);
+  return fdputc (c, __stderr);
 }
