@@ -1,5 +1,7 @@
 ;;; GNU Mes --- Maxwell Equations of Software
-;;; Copyright © 2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2018, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2023 Andrius Štikonas <andrius@stikonas.eu>
+;;; Copyright © 2021 W. J. van der Laan <laanwj@protonmail.com>
 ;;;
 ;;; This file is part of GNU Mes.
 ;;;
@@ -67,9 +69,8 @@
 
 (define (x86_64:function-locals . rest)
   `(
-    ;; FIXME: how on x86_64?
-    ("sub____$i32,%rsp" (#:immediate ,(+ (* 4 1025) (* 20 8))))
-    )) ; 4*1024 buf, 20 local vars
+    ("sub____$i32,%rsp" (#:immediate ,(+ (* 8 1025) (* 20 8))))
+    )) ; 8*1024 buf, 20 local vars
 
 (define (x86_64:r->local info n)
   (let ((r (get-r info))
@@ -82,7 +83,7 @@
   (or v (error "invalid value: x86_64:value->r: " v))
   (let ((r (get-r info)))
     (if (and (>= v 0)
-             (< v #xffffffff))
+             (< v #x80000000))
      `((,(string-append "mov____$i32,%" r) (#:immediate ,v)))
      `((,(string-append "mov____$i64,%" r) (#:immediate8 ,v))))))
 
@@ -429,6 +430,12 @@
     `((,(string-append "mov____%" r1 ",%rcx"))
       (,(string-append "shr____%cl,%" r0)))))
 
+(define (x86_64:r0>>r1-signed info)
+  (let ((r0 (get-r0 info))
+        (r1 (get-r1 info)))
+    `((,(string-append "mov____%" r1 ",%rcx"))
+      (,(string-append "sar____%cl,%" r0)))))
+
 (define (x86_64:r0-and-r1 info)
   (let ((r0 (get-r0 info))
         (r1 (get-r1 info)))
@@ -520,7 +527,7 @@
     (cond ((< (abs v) #x80)
            `((,(string-append "cmp____$i8,%" r) (#:immediate1 ,v))))
           ((and (>= v 0)
-                (< v #xffffffff))
+                (< v #x80000000))
            `((,(string-append "cmp____$i32,%" r) (#:immediate ,v))))
           (else
            `(,(string-append "mov____$i64,%r15") (#:immediate8 ,v)
@@ -608,7 +615,7 @@
     (cond  ((< (abs v) #x80)
             `((,(string-append "addl___$i8,(%" r ")") (#:immediate1 ,v))))
            ((and (>= v 0)
-                 (< v #xffffffff))
+                 (< v #x80000000))
             `((,(string-append "addl___$i32,(%" r ")") (#:immediate ,v))))
            (else
             `((,(string-append "mov____$i64,%r15") (#:immediate8 ,v))
@@ -638,7 +645,7 @@
 (define (x86_64:r-and info v)
   (let ((r (get-r info)))
     (if (and (>= v 0)
-             (< v #xffffffff))
+             (< v #x80000000))
         `((,(string-append "and____$i32,%" r) (#:immediate ,v)))
         `((,(string-append "mov____$i64,%r15") (#:immediate8 ,v))
           (,(string-append "and____%r15,%" r))))))
@@ -751,6 +758,7 @@
     (r0->r1 . ,x86_64:r0->r1)
     (r0->r1-mem . ,x86_64:r0->r1-mem)
     (r0-and-r1 . ,x86_64:r0-and-r1)
+    (r0-cmp-r1 . ,x86_64:r0-r1)
     (r0-mem->r1-mem . ,x86_64:r0-mem->r1-mem)
     (r0-or-r1 . ,x86_64:r0-or-r1)
     (r0-r1 . ,x86_64:r0-r1)
@@ -758,6 +766,7 @@
     (r0/r1 . ,x86_64:r0/r1)
     (r0<<r1 . ,x86_64:r0<<r1)
     (r0>>r1 . ,x86_64:r0>>r1)
+    (r0>>r1-signed . ,x86_64:r0>>r1-signed)
     (r1->r0 . ,x86_64:r1->r0)
     (r2->r0 . ,x86_64:r2->r0)
     (ret . ,x86_64:ret)
