@@ -109,7 +109,7 @@ MES_DEBUG=3 MES_ARENA=10000 MES_MAX_ARENA=10000 MES_BOOT=tests/gc.test out-syste
 #          lib/linux/$mes_cpu-mes-mescc/_write.c\
 #          \
 #          lib/mes/globals.c\
-#          lib/mes/mini-write.c\
+#          lib/mes/write.c\
 #          lib/string/strlen.c\
 #          \
 #          scaffold/hello.c
@@ -123,7 +123,7 @@ cat                                             \
     lib/linux/$mes_cpu-mes-mescc/_write.c       \
                                                 \
     lib/mes/globals.c                           \
-    lib/mes/mini-write.c                        \
+    lib/mes/write.c                             \
     lib/string/strlen.c                         \
                                                 \
     scaffold/hello.c                            \
@@ -263,6 +263,8 @@ $CC -g -D HAVE_CONFIG_H=1                               \
     lib/linux/_read.c                                   \
     lib/linux/time.c                                    \
     lib/linux/unlink.c                                  \
+    include/sys/resource.h                              \
+    lib/linux/wait4.c                                   \
     lib/linux/waitpid.c                                 \
     lib/linux/$mes_cpu-mes-$compiler/syscall.c          \
                                                         \
@@ -313,7 +315,7 @@ MES_DEBUG=3 MES_ARENA=10000 MES_MAX_ARENA=10000 MES_BOOT=tests/gc.test out-mes/m
 #          lib/linux/$mes_cpu-mes-mescc/_write.c\
 #          \
 #          lib/mes/globals.c\
-#          lib/mes/mini-write.c\
+#          lib/mes/write.c\
 #          lib/string/strlen.c\
 #          \
 #          scaffold/hello.c
@@ -327,7 +329,7 @@ cat                                             \
     lib/linux/$mes_cpu-mes-mescc/_write.c       \
                                                 \
     lib/mes/globals.c                           \
-    lib/mes/mini-write.c                        \
+    lib/mes/write.c                             \
     lib/string/strlen.c                         \
                                                 \
     scaffold/hello.c                            \
